#!/bin/sh

# Set default variables.
#
FAILED=0
[ "$TEST_RESULTS" = "" ] && TEST_RESULTS=results.def
ANOMY=..
export ANOMY

# Load local configuration, if it exists.
#
if [ -e tests.conf ]; then
    . tests.conf
    echo "Using configuration from tests.conf - results go in $TEST_RESULTS."
fi
export TEST_RESULTS SAN_CONF

# Minor sanity checks...
#
if [ ! -d "$TEST_RESULTS" ]; then
    echo "No such directory: $TEST_RESULTS"
    exit 1
fi
if [ "$SAN_CONF" != "" -a ! -r "$SAN_CONF" ]; then
    echo "No such file: $SAN_CONF"
    exit 1
fi

# Run tests!
#
echo "Running tests ..."
echo
for a in *.t; do
        test=`echo $a |sed -e 's/\.t$//'`
	/bin/echo -n "$test:	"
	sh $a
	if [ ! -e "$TEST_RESULTS/$test.ok" ]; then
	    cp test.out "$TEST_RESULTS/$test.ok"
	    echo installed
	else
	    if diff test.out "$TEST_RESULTS/$test.ok" >test.diff; then
	        rm -f test.*
	        echo ok
            else
		for t in test.*; do
		    mv -f $t "$TEST_RESULTS"/`echo $t |sed -e "s/^test/$test/"`
		done
	        echo "failed  (moved result files to $TEST_RESULTS)"
		FAILED=1
	    fi
        fi
done

rm -f test.*
echo
[ $FAILED = 0 ] && exit 0

# Beg for feedback...
#
cat <<tac
One or more tests failed!  There are two possible reasons for this:

 1) Something was fixed, and your test-case results need to be updated.
 2) I (the author) broke something.

Please check the change-log to see which it is.  If it's number 1), then
just replace the .ok file with the .out file generated by the failed test,
in your result directory.

Otherwise - if you think something is broken (case 2), please send the
following info to anomy-bugs@mailtools.anomy.net:

 - Architecture (e.g. Sparc, Intel, Alpha. ...)
 - Operating system (e.g. RedHat 6.2, Solaris 8, HP-UX, ...)
 - Perl version (the output of "perl -V")
 - Any relevant Anomy configuration files (e.g. for the sanitizer).
 - Copies of all result files for the failed tests (they should have the
   extensions .ok, .out, .diff and .log).

Thanks!

tac
exit 1

